==> apache-beam-2.59.0-source-release.zip: beam-2.59.0/runners/google-cloud-dataflow-java/worker/src/main/java/org/apache/beam/runners/dataflow/worker/OperationalLimits.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.beam.runners.dataflow.worker;

import com.google.auto.value.AutoBuilder;

/** Keep track of any operational limits required by the backend. */
public class OperationalLimits {
  // Maximum size of a commit from a single work item.
  public final long maxWorkItemCommitBytes;
  // Maximum size of a single output element's serialized key.
  public final long maxOutputKeyBytes;
  // Maximum size of a single output element's serialized value.
  public final long maxOutputValueBytes;
  // Whether to throw an exception when processing output that violates any of the given limits.
  public final boolean throwExceptionOnLargeOutput;

  OperationalLimits(
      long maxWorkItemCommitBytes,
      long maxOutputKeyBytes,
      long maxOutputValueBytes,
      boolean throwExceptionOnLargeOutput) {
    this.maxWorkItemCommitBytes = maxWorkItemCommitBytes;
    this.maxOutputKeyBytes = maxOutputKeyBytes;
    this.maxOutputValueBytes = maxOutputValueBytes;
    this.throwExceptionOnLargeOutput = throwExceptionOnLargeOutput;
  }

  @AutoBuilder(ofClass = OperationalLimits.class)
  public interface Builder {
    Builder setMaxWorkItemCommitBytes(long bytes);

    Builder setMaxOutputKeyBytes(long bytes);

    Builder setMaxOutputValueBytes(long bytes);

    Builder setThrowExceptionOnLargeOutput(boolean shouldThrow);

    OperationalLimits build();
  }

  public static Builder builder() {
    return new AutoBuilder_OperationalLimits_Builder()
        .setMaxWorkItemCommitBytes(Long.MAX_VALUE)
        .setMaxOutputKeyBytes(Long.MAX_VALUE)
        .setMaxOutputValueBytes(Long.MAX_VALUE)
        .setThrowExceptionOnLargeOutput(false);
  }
}

==> apache-beam-2.70.0-source-release.zip: beam-2.70.0/runners/google-cloud-dataflow-java/worker/src/main/java/org/apache/beam/runners/dataflow/worker/OperationalLimits.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.beam.runners.dataflow.worker;

import com.google.auto.value.AutoValue;
import org.apache.beam.sdk.annotations.Internal;

/** Keep track of any operational limits required by the backend. */
@AutoValue
@Internal
public abstract class OperationalLimits {

  // Maximum size of a commit from a single work item.
  public abstract long getMaxWorkItemCommitBytes();
  // Maximum size of a single output element's serialized key.
  public abstract long getMaxOutputKeyBytes();
  // Maximum size of a single output element's serialized value.
  public abstract long getMaxOutputValueBytes();

  @AutoValue.Builder
  public abstract static class Builder {

    public abstract Builder setMaxWorkItemCommitBytes(long bytes);

    public abstract Builder setMaxOutputKeyBytes(long bytes);

    public abstract Builder setMaxOutputValueBytes(long bytes);

    public abstract OperationalLimits build();
  }

  public static OperationalLimits.Builder builder() {
    return new AutoValue_OperationalLimits.Builder()
        .setMaxWorkItemCommitBytes(Long.MAX_VALUE)
        .setMaxOutputKeyBytes(Long.MAX_VALUE)
        .setMaxOutputValueBytes(Long.MAX_VALUE);
  }
}
